@@ -1,7 +1,6 @@
 use {
-    crate::{admin_rpc_service, new_spinner_progress_bar, println_name_value},
+    crate::{admin_rpc_service, new_spinner_progress_bar, println_name_value, ProgressBar},
     console::style,
-    indicatif::ProgressBar,
     solana_client::{
         client_error, rpc_client::RpcClient, rpc_request, rpc_response::RpcContactInfo,
     },
